"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.trainingsRouter = void 0;
const express_1 = require("express");
const training_record_1 = require("../records/training.record");
const errors_1 = require("../utils/errors");
exports.trainingsRouter = (0, express_1.Router)()
    .get('/', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const trainings = yield training_record_1.TrainingRecord.getAll();
    res.json(trainings);
}))
    .get('/:id', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const training = yield training_record_1.TrainingRecord.getOne(req.params.id);
    if (!training) {
        throw new errors_1.ValidationError('Trening z podanym ID nie istnieje. ');
    }
    res.json(training);
}))
    .post('/', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const newTraining = new training_record_1.TrainingRecord(req.body);
    yield newTraining.insert();
    res.json(newTraining);
}))
    .delete('/:id', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    if (req.params.id.startsWith('protected')) {
        throw new errors_1.ValidationError('Ten trening jest chroniony.');
    }
    const training = yield training_record_1.TrainingRecord.getOne(req.params.id);
    if (!training) {
        throw new errors_1.ValidationError('Trening o danym ID nie istnieje w bazie danych.');
    }
    yield training.delete();
    res.json(training.name);
}))
    .patch('/:id', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    if (req.params.id.startsWith('protected')) {
        throw new errors_1.ValidationError('Ten trening jest chroniony.');
    }
    const training = yield training_record_1.TrainingRecord.getOne(req.params.id);
    if (!training) {
        throw new errors_1.ValidationError('Trening o danym ID nie istnieje w bazie danych.');
    }
    const newTraining = new training_record_1.TrainingRecord(Object.assign(Object.assign({}, req.body), { id: training.id }));
    yield newTraining.update();
    res.json(newTraining);
}));
//# sourceMappingURL=trainings.router.js.map